@@ -209,7 +209,7 @@ class AIHClient:
         if(self._is_expired()):
             self._update_token()
         
-        url = f'https://{self.environment}-du-we-api.azurewebsites.net/files/download/{file_id}'
+        url = f'https://{self.environment}-du-we-api.azurewebsites.net/files/{file_id}/Data'
         response = self.client.get(url)
 
         return response.content
