@@ -4,6 +4,8 @@ from .PropertyDefinition import PropertyDefinition
 from .Mitigation import Mitigation
 from .RiskAssessmentResult import RiskAssessmentResult
 from .Risk import Risk
+from .Population import Population
+from .PopulationItem import PopulationItem
 
 
 __all__ = [
@@ -14,4 +16,6 @@ __all__ = [
     'Mitigation',
     'Risk',
     'RiskAssessmentResult',
+    'Population',
+    'PopulationItem'
 ]
\ No newline at end of file
